#
# spec file for package python-pika
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define mod_name pika

Name:           python-%{mod_name}
Version:        0.10.0
Release:        3.2
Url:            http://pika.github.com/
Summary:        Pika Python AMQP Client Library
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/p/pika/pika-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-setuptools
%if 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%else
BuildArch:      noarch
%endif

%description
Pika is a pure-Python implementation of the AMQP 0-9-1 protocol that
tries to stay fairly independent of the underlying network support
library. Pika was developed primarily for use with RabbitMQ, but
should also work with other AMQP 0-9-1 brokers.

%prep
%setup -q -n %{mod_name}-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc README.rst LICENSE
# You may have to add additional files here (documentation and binaries mostly)
%python_sitelib/%{mod_name}*
%python_sitelib/*.egg-info

%changelog
* Wed Mar 16 2016 tbechtold@suse.com
- update to 0.10.0:
  * LibevConnection: Fixed dict chgd size during iteration
  * SelectConnection: Fixed KeyError exceptions in IOLoop timeout executions
  * BlockingConnection: Add support to make BlockingConnection a Context Manager
  * f72b58f - Fixed failure to purge _ConsumerCancellationEvt from
    BlockingChannel._pending_events during basic_cancel.
  * Change to 3-Clause BSD License
  * Python 3.x support
  * Over 150 commits from 19 contributors
  * Refactoring of SelectConnection ioloop
  * This major release contains certain non-backward-compatible API changes as
    well as significant performance improvements in the BlockingConnection
    adapter.
  * Non-backward-compatible changes in Channel.add_on_return_callback
    callback’s signature.
  * The AsynchoreConnection adapter was retired
  * see also https://pika.readthedocs.org/en/0.10.0/version_history.html
- Add and update LICENSE. It's now BSD-3-Clause
- Remove README.md . It's shipped as README.rst in the upstream tarball
* Wed Mar 25 2015 matwey.kornilov@gmail.com
- Update to version 0.9.14
  + Major issue with socket buffer refactor in 0.9.13 (#328) fixes by cooper6581 and Erik Andersson
  + Fix a bug in SelectConnection that did not allow for a IOLoop to be restarted (#337) fix by Ralf Nyrén
  + Fix an issue in BlockingConnection disconnections (#340) fix by Mark Unsworth
  + Add NullHandler to prevent logging warnings when not configured (#339) by Cenk Altı
  + Added Twisted Adapter example (#314) by nolinksoft
* Wed Dec  4 2013 p.drouand@gmail.com
- Update to version 0.9.13
  + IPv6 Support
  + Officially remove support for <= Python 2.5 even though it was
    broken already
  + Drop pika.simplebuffer.SimpleBuffer in favor of the Python stdlib
    collections.deque object
  + New default object for receiving content is a “bytes” object which
    is a str wrapper in Python 2, but paves way for Python 3 support
  + New “Raw” mode for frame decoding content frames (#334) addresses
    issues #331, #229
  + Connection and Disconnection logic refactored, allowing for cleaner
    separation of protocol logic and socket handling logic as well as
    connection state management
  + New “on_open_error_callback” argument in creating connection
    objects and new Connection.add_on_open_error_callback method
  + New Connection.connect method to cleanly allow for reconnection code
  + Support for all AMQP field types, using protocol specified
    signed/unsigned unpacking
  + Method signature for creating connection objects has new argument
    “on_open_error_callback” which is positionally before “on_close_callback”
  + Internal callback variable names in connection.Connection have been
    renamed and constants used. If you relied on any of these callbacks
    outside of their internal use, make sure to check out the new constants.
  + Connection._connect method, which was an internal only method is now
    deprecated and will raise a DeprecationWarning. If you relied on
    this method, your code needs to change.
  + pika.simplebuffer has been removed
  + BlockingConnection consumer generator does not free buffer
    when exited (#328)
  + Unicode body payloads in the blocking adapter raises exception (#333)
  + Support “b” short-short-int AMQP data type (#318)
  + Docstring type fix in adapters/select_connection (#316)
  + IPv6 not supported (#309)
  + Stop the HeartbeatChecker when connection is closed (#307)
  + Unittest fix for SelectConnection (#336)
  + Handle condition where no connection or socket exists but
    SelectConnection needs a timeout for retrying a connection (#322)
  + TwistedAdapter lagging behind BaseConnection changes (#321)
  + Refactored documentation
  + Added Twisted Adapter example (#314)
- Remove CFLAGS definition
- Remove redundant %%clean section
* Thu Mar 21 2013 matwey.kornilov@gmail.com
- Add REAMDE.md
- Fix License tag
* Thu Mar 21 2013 matwey.kornilov@gmail.com
- Update to version 0.9.12:
  - Bugfix: New timeout id hashing was not unique
* Mon Mar 18 2013 matwey.kornilov@gmail.com
- Update to version 0.9.11:
- Changes from 0.9.10
  - Address inconsistent channel close callback documentation and add the signature change to the TwistedChannel class (#305)
  - Address a missed timeout related internal data structure name change introduced in the SelectConnection 0.9.10 release. Update all connection adapters to use same signature and docstring (#306).
* Sun Mar 17 2013 matwey.kornilov@gmail.com
- Updated to version 0.9.10:
- Changes from 0.9.9 to 0.9.10
  - Fix timeout in twisted adapter (Submitted by cellscape)
  - Fix blocking_connection poll timer resolution to milliseconds (Submitted by cellscape)
  - Fix channel._on_close() without a method frame (Submitted by Richard Boulton)
  - Addressed exception on close (Issue #279 - fix by patcpsc)
  - 'messages' not initialized in BlockingConnection.cancel() (Issue #289 fix by Mik Kocikowski)
  - Make queue_unbind behave like queue_bind (Issue #277)
  - Address closing behavioral issues for connections and channels (Issue #275)
  - Pass a Method frame to Channel._on_close in Connection._on_disconnect (Submitted by Jan Urbański)
  - Fix channel closed callback signature in the Twisted adapter (Submitted by Jan Urbański)
  - Don't stop the IOLoop on connection close for in the Twisted adapter (Submitted by Jan Urbański)
  - Update the asynchronous examples to fix reconnecting and have it work
  - Warn if the socket was closed such as if RabbitMQ dies without a Close frame
  - Fix URLParameters ssl_options (Issue #296)
  - Add state to BlockingConnection addressing (Issue #301)
  - Encode unicode body content prior to publishing (Issue #282)
  - Fix an issue with unicode keys in BasicProperties headers key (Issue #280)
  - Change how timeout ids are generated (Issue #254)
  - Address post close state issues in Channel (Issue #302)
  - Change core connection communication behavior to prefer outbound writes over reads, addressing a recursion issue
  - Update connection on close callbacks, changing callback method signature
  - Update channel on close callbacks, changing callback method signature
  - Give more info in the ChannelClosed exception
  - Change the constructor signature for BlockingConnection, block open/close callbacks
  - Disable the use of add_on_open_callback/add_on_close_callback methods in BlockingConnection
- Changes from 0.9.8 to 0.9.9 - lots of bufixes:
  - Only remove the tornado_connection.TornadoConnection file descriptor from the IOLoop if it’s still open (Issue #221)
  - Allow messages with no body (Issue #227)
  - Allow for empty routing keys (Issue #224)
  - Don’t raise an exception when trying to send a frame to a closed connection (Issue #229)
  - Only send a Connection.CloseOk if the connection is still open. (Issue #236 Fix by noleaf)
  - Fix timeout threshold in blocking connection - (Issue #232 - Fix by Adam Flynn)
  - Fix closing connection while a channel is still open (Issue #230 - Fix by Adam Flynn)
  - Fixed misleading warning and exception messages in BaseConnection (Issue #237 Fix by Tristan Penman)
  - Pluralised and altered the wording of the AMQPConnectionError exception (Issue #237 - Fix by Tristan Penman)
  - Fixed _adapter_disconnect in TornadoConnection class (Issue #237 Fix by Tristan Penman)
  - Fixing hang when closing connection without any channel in BlockingConnection (Issue #244 Fix by Ales Teska)
  - Remove the process_timeouts() call in SelectConnection (Issue #239)
  - Change the string validation to basestring for host connection parameters (Issue #231)
  - Add a poller to the BlockingConnection to address latency issues introduced in Pika 0.9.8 (Issue #242)
  - reply_code and reply_text is not set in ChannelException (Issue #250)
  - Add the missing constraint parameter for Channel._on_return callback processing (Issue #257 - Fix by patcpsc)
  - Channel callbacks not being removed from callback manager when channel is closed or deleted (Issue #261)
* Mon Nov 19 2012 matwey.kornilov@gmail.com
- Fixed License: tag
* Mon Nov 19 2012 matwey.kornilov@gmail.com
- Updated to version 0.9.8:
- Bugfixes
  - Channel.queue_declare/BlockingChannel.queue_declare not setting up callbacks property for empty queue name (Issue #218)
  - Channel.queue_bind/BlockingChannel.queue_bind not allowing empty routing key
  - Connection._on_connection_closed calling wrong method in Channel (Issue #219)
  - Fix tx_commit and tx_rollback bugs in BlockingChannel (Issue #217)
- Changes from version 0.9.6 to 0.9.7:
- New features
  - generator based consumer in BlockingChannel (See Using the BlockingChannel.consume generator to consume messages for example)
- Changes
  - BlockingChannel._send_method will only wait if explicitly told to
- Bugfixes
  - Added the exchange “type” parameter back but issue a DeprecationWarning
  - Dont require a queue name in Channel.queue_declare()
  - Fixed KeyError when processing timeouts (Issue # 215 - Fix by Raphael De Giusti)
  - Don’t try and close channels when the connection is closed (Issue #216 - Fix by Charles Law)
  - Dont raise UnexpectedFrame exceptions, log them instead
  - Handle multiple synchronous RPC calls made without waiting for the call result (Issues #192, #204, #211)
  - Typo in docs (Issue #207 Fix by Luca Wehrstedt)
  - Only sleep on connection failure when retry attempts are > 0 (Issue #200)
  - Bypass _rpc method and just send frames for Basic.Ack, Basic.Nack, Basic.Reject (Issue #205)
* Tue Oct 30 2012 matwey.kornilov@gmail.com
  `
- Updated to version 0.9.6
- New features and highlights:
  - Delivery confirmation support
  - New URLParameters class for connecting with AMQP URLs
  - BlockingConnection will raise exceptions for various events, such as
  channel and connection closures.
  - New BlockingConnection methods:
  - process_data_events() - Force BlockingConnection to check for pending
  events from RabbitMQ
  - sleep() - Sleep without blocking communication with RabbitMQ
  - New BlockingChannel methods:
  - start_consuming()
  - stop_consuming()
  - Back-pressure detection is now optional via a connection parameter
  - Configurable IOLoop stopping on asynchronous adapters
  - Rewritten unit test coverage from the ground up. While not complete, it
  is a significant improvement over previous releases.
- Major bugfix areas:
  - Connection handling
  - Blocking functionality in the BlockingConnection
  - SSL
  - UTF-8 Handling
- Things removed:
  - pika.reconnection_strategies
  - pika.channel.ChannelTransport
  - pika.log
  - pika.template
  - examples directory, adding examples to documentation instead.
  - functional tests
* Tue Sep 27 2011 matwey.kornilov@gmail.com
- Updated to version 0.9.5
- Spec regenerated from PIP using py2pack
* Fri Feb 12 2010 jblunck@suse.de
- The entire module is platform-independent, so lets make it noarch.
* Fri Jan  8 2010 jblunck@suse.de
- Initial package
